@@ -470,7 +470,11 @@ static PyObject* pytun_tuntap_get_mtu(PyObject* self, void* d)
         return NULL;
     }
 
+#if PY_MAJOR_VERSION >= 3
     return PyLong_FromLong(req.ifr_mtu);
+#else
+    return PyInt_FromLong(req.ifr_mtu);
+#endif
 }
 
 static int pytun_tuntap_set_mtu(PyObject* self, PyObject* value, void* d)
@@ -592,7 +596,11 @@ static PyObject* pytun_tuntap_read(PyObject* self, PyObject* args)
     }
 
     /* Allocate a new string */
+#if PY_MAJOR_VERSION >= 3
     buf = PyBytes_FromStringAndSize(NULL, rdlen);
+#else
+    buf = PyString_FromStringAndSize(NULL, rdlen);
+#endif
     if (buf == NULL)
     {
         return NULL;
@@ -600,7 +608,11 @@ static PyObject* pytun_tuntap_read(PyObject* self, PyObject* args)
 
     /* Read data */
     Py_BEGIN_ALLOW_THREADS
+#if PY_MAJOR_VERSION >= 3
     outlen = read(tuntap->fd, PyBytes_AS_STRING(buf), rdlen);
+#else
+    outlen = read(tuntap->fd, PyString_AS_STRING(buf), rdlen);
+#endif
     Py_END_ALLOW_THREADS
     if (outlen < 0)
     {
@@ -613,7 +625,11 @@ static PyObject* pytun_tuntap_read(PyObject* self, PyObject* args)
     {
         /* We did not read as many bytes as we anticipated, resize the
            string if possible and be successful. */
+#if PY_MAJOR_VERSION >= 3
         if (_PyBytes_Resize(&buf, outlen) < 0)
+#else
+        if (_PyString_Resize(&buf, outlen) < 0)
+#endif
         {
             return NULL;
         }
@@ -646,7 +662,11 @@ static PyObject* pytun_tuntap_write(PyObject* self, PyObject* args)
         return NULL;
     }
 
+#if PY_MAJOR_VERSION >= 3
     return PyLong_FromSsize_t(written);
+#else
+    return PyInt_FromSsize_t(written);
+#endif
 }
 
 PyDoc_STRVAR(pytun_tuntap_write_doc,
@@ -654,7 +674,11 @@ PyDoc_STRVAR(pytun_tuntap_write_doc,
 
 static PyObject* pytun_tuntap_fileno(PyObject* self)
 {
+#if PY_MAJOR_VERSION >= 3
     return PyLong_FromLong(((pytun_tuntap_t*)self)->fd);
+#else
+    return PyInt_FromLong(((pytun_tuntap_t*)self)->fd);
+#endif
 }
 
 PyDoc_STRVAR(pytun_tuntap_fileno_doc,
